@@ -4,7 +4,7 @@ use strict;
 use LWP::UserAgent ();
 use Carp ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $DOMAIN = 'antigate.com'; # service domain often changes because of the abuse
 our $WAIT   = 220;            # default time that recognize() or upload() can work
@@ -29,7 +29,9 @@ my %MESSAGES =
     'ERROR_IMAGE_IS_NOT_GIF'         => 'captcha is not correct gif file',
     'ERROR_ZERO_BALANCE'             => 'you have a zero balance',
     'CAPCHA_NOT_READY'               => 'captcha is not recognized yet',
-    'OK_REPORT_RECORDED'             => 'your abuse recorded'
+    'OK_REPORT_RECORDED'             => 'your abuse recorded',
+    'ERROR_CAPTCHA_UNSOLVABLE'       => 'captcha can\'t be recognized',
+    'ERROR_BAD_DUPLICATES'           => 'captcha duplicates limit reached'
 );
 
 
@@ -136,7 +138,7 @@ sub try_upload
         return undef;
     }
     
-    return $captcha_id;
+    return $self->{last_captcha_id} = $captcha_id;
 }
 
 
@@ -229,6 +231,13 @@ sub upload_and_recognize
 }
 
 
+sub last_captcha_id
+{
+    my ($self) = @_;
+    return $self->{last_captcha_id};
+}
+
+
 sub abuse
 {
     my ($self, $id) = @_;
@@ -477,12 +486,14 @@ associated with this error type. It should be one of the:
   'ERROR_IMAGE_IS_NOT_JPEG'
   'ERROR_IMAGE_IS_NOT_GIF'
   'ERROR_ZERO_BALANCE'
+  'ERROR_CAPTCHA_UNSOLVABLE'
+  'ERROR_BAD_DUPLICATES'
   'HTTP_ERROR'
 
 =item $recognizer->errstr
 
 This method gets an error from previous unsuccessful operation. The Error is returned as a string which
-describs the problem.
+describes the problem.
 
 =item $recognizer->try_upload(%options)
 
@@ -531,6 +542,11 @@ This method uploads and recognizes captcha in one step. It is easier but less fl
 with the one in method try_upload(). On success will return recognized captcha text. On failure returns undef and sets
 errno and errstr.
 
+=item $recognizer->last_captcha_id
+
+This method returns id of the last successfully uploaded captcha. This can be useful when you used upload_and_recognize()
+and then want to use some method that accepts captcha id as argument (abuse() for example).
+
 =item $recognizer->abuse($captcha_id)
 
 This method sends a message to the service that captcha with $captcha_id was recognized incorrectly. On success will return
